@@ -1,11 +1,16 @@
-import sqlite3
+#Standart library imports
 import sys
 import os
 import traceback
 import logging
 from typing import Tuple, Any
-from sqlite3 import OperationalError
 from shutil import copyfile
+import logging
+from pathlib import Path
+
+#sqlite3 imports
+import sqlite3
+from sqlite3 import OperationalError
 
 class SimpleSqlite():
 
@@ -15,53 +20,53 @@ class SimpleSqlite():
         Args:
             dbfile (str): Path to database
         """
+        logging.basicConfig(level=logging.INFO)
+
         self.conn : Any = None
         self.dbFile : str = dbfile
 
+        self.connect_to_db(self.dbFile)
+
     def __del__(self):
         if self.conn != None: 
             self.conn.close()
 
-    def create_database(self) -> Tuple[bool, str]:
+    def connect_to_db(self, dbfile : str = ''):
+        try:
+            if not dbfile:
+                dbfile = self.dbFile
+
+            self.conn = sqlite3.connect(dbfile)
+            logging.info(f'Successfully connected to database "{Path(dbfile).stem}"')
+
+        except Exception:
+            logging.error(traceback.format_exc())
+
+
+    def create_database(self) -> None:
         """Creates the database (.db file) with specified name
-
-        Returns:
-            Tuple of bool and str
-
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             
         Raises:
             Except: If unexpected error raised. 
 
         """
 
-        result_run : bool = False
-        message_run : str = ''
         
         try:
-            if os.path.isfile(self.dbFile):
+            if Path(self.dbFile).is_file():
                 os.remove(self.dbFile)
 
-            result, message = self.open_database()
-            if not result:
-                logging.error(message)
-                return result, message
+            self.conn = sqlite3.connect(self.dbFile)
 
-            if not os.path.isfile(self.dbFile):
+            if not Path(self.dbFile).is_file():
                 message = f'Cannot create dbfile: {self.dbFile}'
-                logging.error(message)
-                return result_run, message    
+                raise FileNotFoundError(message)  
 
-            result_run = True
-
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run
-
-    def open_database(self) -> Tuple[bool, str]:
+    def open_database(self) -> None:
         """Opens the database
 
         Returns:
@@ -75,21 +80,19 @@ class SimpleSqlite():
 
         """
 
-        result_run : bool = False
-        message_run : str = ''
-
         try:
-            self.conn = sqlite3.connect(self.dbFile)
+            
+            message = """This is old method for opening database and soon will be closed. 
+                        Please use method "connect_to_db" if you want to use another database"""
+            logging.warning(message)
 
-            result_run = True
+            self.connect_to_db(self.dbFile)
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run
-
-    def create_table(self, tablename : str, strSql : str) -> Tuple[bool, str, str, list[str], list[str]]:
+    def create_table(self, tablename : str, strSql : str) -> Tuple[str, list[str], list[str]]:
         """Creates the table in database with specified table name
 
         Args:
@@ -99,10 +102,8 @@ class SimpleSqlite():
             Pass as 'CREATE TABLE lessons ("lesson_number" text, "lesson_name" text)'
 
         Returns:
-            Tuple of bool, str, str, list[str] and list[str]
+            Tuple of str, list[str] and list[str]
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             tableName (str)         : Table name of the created table
             namesFields (list[str]) : All fields of the created table
             typeFields  (list[str]) : Type of all fields of the created table
@@ -112,14 +113,11 @@ class SimpleSqlite():
 
         """
 
-        result_run : bool = False
-        message_run : str = ''
         tableName : str = ''
         namesFields : list[str] = []
         typeFields : list[str] = []
 
         try:
-            logging.debug(f'create_table tablename: {tablename} strSql: {strSql}')
         
             self.conn.execute(strSql) 
             strSql = "select name from sqlite_master WHERE type='table' AND name='{}'".format(tablename)
@@ -134,15 +132,13 @@ class SimpleSqlite():
                 namesFields.append(row[0])    
                 typeFields.append(row[1])
 
-            result_run = True
-
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run, tableName, namesFields, typeFields
+        return tableName, namesFields, typeFields
 
-    def insert_table(self, tablename : str, data : list[Any], mode : str = '', replace_symbol : bool = False) -> Tuple[bool, str]:
+    def insert_table(self, tablename : str, data : list[Any], mode : str = '', replace_symbol : bool = False) -> None:
         """Inserts specific data to specific table in database
 
         Args:
@@ -150,22 +146,15 @@ class SimpleSqlite():
             data (list[Any])        : Specified data which will be used for insertion
             mode (str)              : Delete all previously created data or not. Defaults to empty string.
             replace_symbol (bool)   : Delete symbol ' and " before inserting data. Defaults to False.
-
-        Returns:
-            Tuple of bool and str
-
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             
         Raises:
             Except: If unexpected error raised. 
 
         """
 
-        result_run : bool = False
-        message_run : str = ''
         rec : list[str] = []
         str_fields : str = ''
+        insData = None
 
         try:
             
@@ -182,10 +171,8 @@ class SimpleSqlite():
             namesFields = []
             rows = cur.fetchall()
             for row in rows:
-                result, message, is_autoincrement = self.__check_autoincrement_by_field(tablename, row[0])
-                if not result:
-                    logging.error(message)
-                    return result, message
+                is_autoincrement = self.__check_autoincrement_by_field(tablename, row[0])
+
                 if not is_autoincrement:
                     namesFields.append(row[0]) 
                     str_fields = str_fields + row[0] + "," 
@@ -210,29 +197,24 @@ class SimpleSqlite():
                 self.conn.execute(insData)
             self.conn.commit()
 
-            result_run = True 
-
         except OperationalError:
             message_run = f'OperationalError error: {str(traceback.format_exc())} tablename : {tablename} insData : {insData}'
             logging.error(message_run)
 
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run
 
-    def select_table(self, tablename : str) -> Tuple[bool, str, list[str]]:
+    def select_table(self, tablename : str) -> list[str]:
         """Selects data in specific table in database
 
         Args:
             tablename (str)  : Specific table name which will be used for getting data.
 
         Returns:
-            Tuple of bool, str and list[str]
+            list[str]
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             rows (list[str])        : All data from the specified table.
             
         Raises:
@@ -240,8 +222,6 @@ class SimpleSqlite():
 
         """
 
-        result_run : bool = False
-        message_run : str = ''
         rows : list[str] = []
         strSql : str = "SELECT name FROM PRAGMA_TABLE_INFO('" + tablename + "')"
 
@@ -264,17 +244,13 @@ class SimpleSqlite():
             cur = self.conn.execute(strSql)
             rows = cur.fetchall()
 
-            logging.debug(f'rows:{rows}')
-
-            result_run = True 
-
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run, rows
+        return rows
 
-    def __check_autoincrement_by_field(self, tablename : str, column_name : str) -> Tuple[bool, str, bool]:
+    def __check_autoincrement_by_field(self, tablename : str, column_name : str) -> bool:
         """Check autoincrement by field in specific table in database
 
         Args:
@@ -293,8 +269,6 @@ class SimpleSqlite():
 
         """
 
-        result_run : bool = False
-        message_run : str = ''
         is_autoincrement : bool = False
 
         try:
@@ -341,19 +315,17 @@ class SimpleSqlite():
                             is_autoincrement = True
                 except:
                     if str(sys.exc_info()[1]) == 'no such table: sqlite_sequence':
-                        return True, message_run, is_autoincrement 
+                        return is_autoincrement 
                     else:
                         raise   
 
-            result_run = True
-
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run, is_autoincrement
+        return is_autoincrement
 
-    def select_sql_script(self, sql_script : str)  -> Tuple[bool, str, list[Any]]:
+    def select_sql_script(self, sql_script : str)  -> list[Any]:
         """Selects data by specified sql script
 
         Args:
@@ -361,10 +333,8 @@ class SimpleSqlite():
             Pass as "SELECT number from numbers".
 
         Returns:
-            Tuple of bool, str and list[Any]
+            list[Any]
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             rows (list[Any])        : All data from the specified sql script.
             
         Raises:
@@ -372,8 +342,6 @@ class SimpleSqlite():
 
         """
 
-        result_run : bool = False
-        message_run : str = ''
         rows : list[Any] = []
 
         try:
@@ -381,15 +349,13 @@ class SimpleSqlite():
             cur = self.conn.execute(sql_script) 
             rows = cur.fetchall()
 
-            result_run = True 
-
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run, rows 
+        return rows 
 
-    def execute_sql_script(self, sql_script : str) -> Tuple[bool, str]:
+    def execute_sql_script(self, sql_script : str) -> None:
         """Executes specified sql script in database
 
         Args:
@@ -406,67 +372,47 @@ class SimpleSqlite():
 
         """
 
-        result_run : bool = False
-        message_run : str = ''
-
         try:
             
             self.conn.execute(sql_script)
             self.conn.commit()
 
-            result_run = True 
-
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run
-
-    def replace_database(self, full_name_database_src : str, full_name_database_dst : str) -> Tuple[bool, str]:
+    def replace_database(self, full_name_database_src : str, full_name_database_dst : str) -> None:
         """Function for replacing databases
 
         Args:
             full_name_database_src (str): Full path of source / original database
             full_name_database_dst (str): Full path of destination database
-
-        Returns:
-            Tuple of bool and str
-
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             
         Raises:
             Except: If unexpected error raised. 
 
         """
-        result_run : bool = False
-        message_run : str = ''
+
         try:
 
-            if not os.path.exists(full_name_database_src):
-                message_run = f'Source database does not exist on the given path : {full_name_database_src}'
-                logging.error(message_run)
-                return result_run, message_run
+            if not Path(full_name_database_src).exists():
+                message_run = f'Source database does not exist on the given path: {full_name_database_src}'
+                raise FileNotFoundError(message_run)
 
-            if os.path.exists(full_name_database_dst):
+            if Path(full_name_database_dst).exists():
                 os.remove(full_name_database_dst)
 
             copyfile(full_name_database_src, full_name_database_dst)
 
-            if not os.path.exists(full_name_database_dst):
-                message_run = f'Destination database does not exists on the given path : {full_name_database_dst}'
-                logging.error(message_run)
-                return result_run, message_run
-            
-            result_run = True
+            if not Path(full_name_database_dst).exists():
+                message_run = f'Destination database does not exists on the given path: {full_name_database_dst}'
+                raise FileNotFoundError(message_run)
     
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run
-
-    def create_view(self, viewname : str, strSql : str) -> Tuple[bool, str, str, list[str], list[str]]:
+    def create_view(self, viewname : str, strSql : str) -> Tuple[str, list[str], list[str]]:
         """Creates view in database
 
         Args:
@@ -475,17 +421,13 @@ class SimpleSqlite():
             Pass as "CREATE VIEW numbers (number text) AS SELECT number FROM all_numbers"
 
         Returns:
-            Tuple of bool, str, str, list[str] and list[str]
+            Tuple of str, list[str] and list[str]
 
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             viewName (str)          : View name of the created view
             namesFields (list[str]) : All fields of the created view
             typeFields  (list[str]) : Type of all fields of the created view
 
         """
-        result_run : bool = False
-        message_run : str = ''
         viewName : str = '' 
         namesFields : list[str] = [] 
         typeFields : list[str] = []
@@ -505,16 +447,14 @@ class SimpleSqlite():
             for row in rows:
                 namesFields.append(row[0])    
                 typeFields.append(row[1])
-                
-            result_run = True
             
-        except:
+        except Exception:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run, viewName, namesFields, typeFields
+        return viewName, namesFields, typeFields
 
-    def open_view(self, viewname : str, filter = None) -> Tuple[bool, str, list[Any]]:
+    def open_view(self, viewname : str, filter = None) -> list[Any]:
         """Open specific view by name
 
         Args:
@@ -522,14 +462,11 @@ class SimpleSqlite():
             filter          : Specific that will be used]. Defaults to None.
 
         Returns:
-            Tuple of bool, str and list[Any]
+            list[Any]
         
-            result_run (bool)       : True if function passed correctly, False otherwise.
-            message_run (str)       : Empty string if function passed correctly, non-empty string if error.
             data (list[Any])        : All data in specific view.
         """
-        result_run : bool = False
-        message_run : str = ''
+        
         data : list[Any] = []
 
         try:
@@ -542,10 +479,9 @@ class SimpleSqlite():
             cur = self.conn.execute(strSql)
             data = cur.fetchall() 
 
-            result_run = True
         except:
             message_run = f'Unexcepted error: {str(traceback.format_exc())}'
             logging.error(message_run)
 
-        return result_run, message_run, data
+        return data
         
\ No newline at end of file
